@@ -5,14 +5,11 @@
 #include <string>
 
 namespace stan {
-  namespace lang {
+namespace lang {
 
-    ill_formed_type::ill_formed_type() : is_data_(false) { }
+ill_formed_type::ill_formed_type() : is_data_(false) {}
 
-    std::string ill_formed_type::oid() const {
-      return "00_ill_formed_type";
-    }
-  }
-}
+std::string ill_formed_type::oid() const { return "00_ill_formed_type"; }
+}  // namespace lang
+}  // namespace stan
 #endif
-
