@@ -17,8 +17,9 @@ template <typename T>
 void stan_print(std::ostream* o, const std::vector<T>& x) {
   *o << '[';
   for (size_t i = 0; i < x.size(); ++i) {
-    if (i > 0)
+    if (i > 0) {
       *o << ',';
+    }
     stan_print(o, x[i]);
   }
   *o << ']';
@@ -28,8 +29,9 @@ template <typename T>
 void stan_print(std::ostream* o, const Eigen::Matrix<T, Eigen::Dynamic, 1>& x) {
   *o << '[';
   for (int i = 0; i < x.size(); ++i) {
-    if (i > 0)
+    if (i > 0) {
       *o << ',';
+    }
     stan_print(o, x(i));
   }
   *o << ']';
@@ -39,8 +41,9 @@ template <typename T>
 void stan_print(std::ostream* o, const Eigen::Matrix<T, 1, Eigen::Dynamic>& x) {
   *o << '[';
   for (int i = 0; i < x.size(); ++i) {
-    if (i > 0)
+    if (i > 0) {
       *o << ',';
+    }
     stan_print(o, x(i));
   }
   *o << ']';
@@ -51,12 +54,14 @@ void stan_print(std::ostream* o,
                 const Eigen::Matrix<T, Eigen::Dynamic, Eigen::Dynamic>& x) {
   *o << '[';
   for (int i = 0; i < x.rows(); ++i) {
-    if (i > 0)
+    if (i > 0) {
       *o << ',';
+    }
     *o << '[';
     for (int j = 0; j < x.row(i).size(); ++j) {
-      if (j > 0)
+      if (j > 0) {
         *o << ',';
+      }
       stan_print(o, x.row(i)(j));
     }
     *o << ']';
