@@ -1,19 +1,20 @@
 #ifndef STAN_MATH_REV_SCAL_FUN_EXP_HPP
 #define STAN_MATH_REV_SCAL_FUN_EXP_HPP
 
+#include <stan/math/rev/meta.hpp>
 #include <stan/math/rev/core.hpp>
 #include <cmath>
 
 namespace stan {
 namespace math {
 
-namespace {
+namespace internal {
 class exp_vari : public op_v_vari {
  public:
   explicit exp_vari(vari* avi) : op_v_vari(std::exp(avi->val_), avi) {}
   void chain() { avi_->adj_ += adj_ * val_; }
 };
-}  // namespace
+}  // namespace internal
 
 /**
  * Return the exponentiation of the specified variable (cmath).
@@ -37,7 +38,7 @@ class exp_vari : public op_v_vari {
  * @param a Variable to exponentiate.
  * @return Exponentiated variable.
  */
-inline var exp(const var& a) { return var(new exp_vari(a.vi_)); }
+inline var exp(const var& a) { return var(new internal::exp_vari(a.vi_)); }
 
 }  // namespace math
 }  // namespace stan
